/* BdfServer - Copyright (c) 2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.storage;

import fr.exemole.bdfserver.api.storage.StorageContent;
import fr.exemole.bdfserver.api.storage.TemplateStorage;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import net.fichotheque.exportation.transformation.TemplateDef;


/**
 *
 * @author Vincent Calame
 */
public class TemplateStorageUnitBuilder {

    private final String type;
    private final TemplateDef templateDef;
    private final Map<String, StorageContent> storageContentMap = new LinkedHashMap<String, StorageContent>();

    public TemplateStorageUnitBuilder(String type, TemplateDef templateDef) {
        this.type = type;
        this.templateDef = templateDef;
    }

    public TemplateStorageUnitBuilder addStorageContent(StorageContent storageContent) {
        storageContentMap.put(storageContent.getPath(), storageContent);
        return this;
    }

    public TemplateStorageUnitBuilder addStorageContent(String path, String text) {
        storageContentMap.put(path, StorageUtils.toStorageContent(path, text));
        return this;
    }

    public TemplateStorageUnitBuilder addStorageContent(String path, byte[] array) {
        storageContentMap.put(path, StorageUtils.toStorageContent(path, array));
        return this;
    }

    public TemplateStorage.Unit toTemplateStorageUnit() {
        List<StorageContent> storageContentList = StorageUtils.wrap(storageContentMap.values().toArray(new StorageContent[storageContentMap.size()]));
        return new InternalTemplateStorageUnit(type, templateDef, storageContentList);
    }

    public static TemplateStorageUnitBuilder init(String type, TemplateDef templateDef) {
        return new TemplateStorageUnitBuilder(type, templateDef);
    }


    private static class InternalTemplateStorageUnit implements TemplateStorage.Unit {

        private final String type;
        private final TemplateDef templateDef;
        private final List<StorageContent> storageContentList;

        private InternalTemplateStorageUnit(String type, TemplateDef templateDef, List<StorageContent> storageContentList) {
            this.type = type;
            this.templateDef = templateDef;
            this.storageContentList = storageContentList;
        }

        @Override
        public TemplateDef getTemplateDef() {
            return templateDef;
        }

        @Override
        public String getType() {
            return type;
        }

        @Override
        public List<StorageContent> getStorageContentList() {
            return storageContentList;
        }

    }

}
