/* BdfServer_Email - Copyright (c) 2011-2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.email;

import net.mapeadores.util.localisation.LocalisationUtils;
import net.mapeadores.util.localisation.Message;


/**
 *
 * @author Vincent Calame
 */
public class WrongAddress {

    public static final short REDACTEUR_NOADRESS_ERROR = 1;
    public static final short REDACTEUR_INACTIVE_ERROR = 2;
    public static final short REDACTEUR_UNKNOWN_ERROR = 3;
    public static final short MALFORMED_ADDRESS_ERROR = 4;
    private final short errorType;
    private final String errorValue;
    private final Message errorMessage;

    private WrongAddress(short errorType, String errorValue, String errorMessageKey, Object... values) {
        this.errorType = errorType;
        this.errorValue = errorValue;
        this.errorMessage = LocalisationUtils.toMessage(errorMessageKey, values);
    }

    public static WrongAddress redacteurNoAdressError(String errorValue) {
        return new WrongAddress(REDACTEUR_NOADRESS_ERROR, errorValue, "_ error.unknown.redacteuraddress");
    }

    public static WrongAddress redacteurInactiveError(String errorValue) {
        return new WrongAddress(REDACTEUR_INACTIVE_ERROR, errorValue, "_ error.unsupported.inactiveredacteur");
    }

    public static WrongAddress redacteurUnknownError(String errorValue) {
        return new WrongAddress(REDACTEUR_UNKNOWN_ERROR, errorValue, "_ error.unknown.redacteur", errorValue);
    }

    public static WrongAddress malformedAddressError(String errorValue) {
        return new WrongAddress(MALFORMED_ADDRESS_ERROR, errorValue, "_ error.wrong.address");
    }

    public short getErrorType() {
        return errorType;
    }

    public String getErrorValue() {
        return errorValue;
    }

    public Message getErrorMessage() {
        return errorMessage;
    }

}
