/* BdfServer_Html - Copyright (c) 2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.consumers;

import java.util.function.Consumer;
import net.mapeadores.util.html.HtmlPrinter;
import net.mapeadores.util.html.HtmlWrapper;
import net.mapeadores.util.html.WrapperFactory;


/**
 *
 * @author Vincent Calame
 */
public class PageUnit implements Consumer<HtmlPrinter> {

    public final static HtmlWrapper SIMPLE = WrapperFactory.div("unit-SimpleUnit");
    public final static Consumer<HtmlPrinter> END = new End();
    private Object titleL10nObject;
    private String action;
    private String sectionCssClasses;
    private String family;
    private Consumer<HtmlPrinter> icon;

    public PageUnit() {

    }

    public PageUnit(Object l10nObject) {
        this.titleL10nObject = l10nObject;
    }

    public PageUnit action(String action) {
        this.action = action;
        return this;
    }

    public PageUnit title(Object titleL10nObject) {
        this.titleL10nObject = titleL10nObject;
        return this;
    }

    public PageUnit title(Runnable titleRunnable) {
        this.titleL10nObject = titleRunnable;
        return this;
    }

    public PageUnit sectionCss(String sectionCssClasses) {
        this.sectionCssClasses = sectionCssClasses;
        return this;
    }

    public PageUnit icon(Consumer<HtmlPrinter> icon) {
        this.icon = icon;
        return this;
    }

    public PageUnit family(String family) {
        this.family = family;
        return this;
    }

    @Override
    public void accept(HtmlPrinter hp) {
        boolean withFamily = (family != null);
        String finalSectionClasses;
        if (sectionCssClasses != null) {
            finalSectionClasses = sectionCssClasses;
        } else {
            finalSectionClasses = "unit-Unit";
        }
        if (withFamily) {
            finalSectionClasses = finalSectionClasses + " family-Colors " + family;
        }
        String finalHeaderClasses;
        if (withFamily) {
            finalHeaderClasses = "unit-Header family-Colors";
        } else {
            finalHeaderClasses = "unit-Header";
        }
        StringBuilder h1Buf = new StringBuilder();
        h1Buf.append("unit-Title");
        if (action != null) {
            h1Buf.append(" ");
            h1Buf.append(action);
        }
        if (withFamily) {
            h1Buf.append(" family-Colors");
        }
        Consumer<HtmlPrinter> finalIcon;
        if (icon != null) {
            finalIcon = icon;
        } else {
            finalIcon = Button.ICON;
        }
        hp
                .SECTION(finalSectionClasses)
                .HEADER(finalHeaderClasses)
                .H1(h1Buf.toString())
                .__(finalIcon);
        if (titleL10nObject != null) {
            hp
                    .__localize(titleL10nObject);
        }
        hp
                ._H1()
                ._HEADER()
                .DIV("unit-Body");
    }

    public static PageUnit start() {
        return new PageUnit();
    }

    public static PageUnit start(Object titleL10nObject) {
        return (new PageUnit(titleL10nObject));
    }

    public static PageUnit start(String action, Object titleL10nObject) {
        return (new PageUnit(titleL10nObject)).action(action);
    }

    public static Consumer<HtmlPrinter> end() {
        return END;
    }


    private static class End implements Consumer<HtmlPrinter> {

        private End() {
        }

        @Override
        public void accept(HtmlPrinter hp) {
            hp
                    ._DIV()
                    ._SECTION();
        }

    }

}
