/* BdfServer_Multi - Copyright (c) 2021-2022 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.multi.jsonproducers.admin;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.multi.api.Multi;
import fr.exemole.bdfserver.tools.synthesis.RedacteurSynthesis;
import fr.exemole.bdfserver.tools.synthesis.SphereSynthesis;
import java.io.IOException;
import net.mapeadores.util.json.JSONWriter;
import net.mapeadores.util.json.JsonProperty;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.logging.ErrorMessageException;
import net.mapeadores.util.text.Label;
import net.mapeadores.util.text.LabelUtils;


/**
 *
 * @author Vincent Calame
 */
public class PersonJsonProperty implements JsonProperty {

    private final Multi multi;
    private final SphereSynthesis sphereSynthesis;
    private final RedacteurSynthesis redacteurSynthesis;
    private final Lang lang;

    public PersonJsonProperty(Multi multi, SphereSynthesis sphereSynthesis, RedacteurSynthesis redacteurSynthesis, Lang lang) {
        this.multi = multi;
        this.sphereSynthesis = sphereSynthesis;
        this.redacteurSynthesis = redacteurSynthesis;
        this.lang = lang;
    }

    @Override
    public void write(JSONWriter jw) throws IOException {
        String[] fichothequeNameArray = sphereSynthesis.getFichothequeNameArray();
        jw.key("sphereName")
                .value(sphereSynthesis.getSphereName());
        jw.key("login")
                .value(redacteurSynthesis.getLogin());
        jw.key("completeName")
                .value(redacteurSynthesis.getCompleteName());
        jw.key("email")
                .value(redacteurSynthesis.getEmail());
        jw.key("statusArray");
        jw.array();
        for (String fichothequeName : fichothequeNameArray) {
            RedacteurSynthesis.FichothequeStatus status = redacteurSynthesis.getFichothequeStatus(fichothequeName);
            if (status == null) {
                continue;
            }
            jw.object();
            {
                jw.key("fichothequeName")
                        .value(fichothequeName);
                jw.key("fichothequeTitle")
                        .value(getFichothequeTitle(fichothequeName));
                jw.key("level")
                        .value(getLevelStringCell(status.getLevel()));
                if (status.hasSpecificName()) {
                    jw.key("specificName")
                            .value(status.getSpecificName());
                }
                if (status.hasSpecificEmail()) {
                    jw.key("specificEmail")
                            .value(status.getSpecificEmail());
                }
            }
            jw.endObject();
        }
        jw.endArray();
    }

    private String getFichothequeTitle(String fichothequeName) {
        try {
            BdfServer bdfServer = multi.getBdfServer(fichothequeName);
            Label label = LabelUtils.getLangPartCheckedLabel(bdfServer.getFichotheque().getFichothequeMetadata().getTitleLabels(), lang);
            if (label != null) {
                return label.getLabelString();
            } else {
                return "";
            }
        } catch (ErrorMessageException eme) {
            return "";
        }
    }

    private static String getLevelStringCell(short level) {
        switch (level) {
            case RedacteurSynthesis.ADMIN_LEVEL:
                return "admin";
            case RedacteurSynthesis.INACTIVE_LEVEL:
                return "inactive";
            default:
                return "user";
        }
    }

}
